# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class V1NetworkAgentsLogsReadsTimestampSearchRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "logs_read_timestamp_entity_id": "IdNumber",
        "logs_read_timestamp_entity_type": "LogsReadTimestampEntityType",
        "logs_read_timestamp_last_read_timestamp": "DefaultString",
    }

    attribute_map = {
        "logs_read_timestamp_entity_id": "logs_read_timestamp_entity_id",
        "logs_read_timestamp_entity_type": "logs_read_timestamp_entity_type",
        "logs_read_timestamp_last_read_timestamp": "logs_read_timestamp_last_read_timestamp",
    }

    def __init__(
        self,
        logs_read_timestamp_entity_id=None,
        logs_read_timestamp_entity_type=None,
        logs_read_timestamp_last_read_timestamp=None,
    ):  # noqa: E501
        """V1NetworkAgentsLogsReadsTimestampSearchRequest - a model defined in Swagger"""  # noqa: E501
        self._logs_read_timestamp_entity_id = None
        self._logs_read_timestamp_entity_type = None
        self._logs_read_timestamp_last_read_timestamp = None
        self.discriminator = None
        self.logs_read_timestamp_entity_id = logs_read_timestamp_entity_id
        self.logs_read_timestamp_entity_type = logs_read_timestamp_entity_type
        self.logs_read_timestamp_last_read_timestamp = (
            logs_read_timestamp_last_read_timestamp
        )

    @property
    def logs_read_timestamp_entity_id(self):
        """Gets the logs_read_timestamp_entity_id of this V1NetworkAgentsLogsReadsTimestampSearchRequest.  # noqa: E501


        :return: The logs_read_timestamp_entity_id of this V1NetworkAgentsLogsReadsTimestampSearchRequest.  # noqa: E501
        :rtype: IdNumber
        """
        return self._logs_read_timestamp_entity_id

    @logs_read_timestamp_entity_id.setter
    def logs_read_timestamp_entity_id(self, logs_read_timestamp_entity_id):
        """Sets the logs_read_timestamp_entity_id of this V1NetworkAgentsLogsReadsTimestampSearchRequest.


        :param logs_read_timestamp_entity_id: The logs_read_timestamp_entity_id of this V1NetworkAgentsLogsReadsTimestampSearchRequest.  # noqa: E501
        :type: IdNumber
        """
        if logs_read_timestamp_entity_id is None:
            raise ValueError(
                "Invalid value for `logs_read_timestamp_entity_id`, must not be `None`"
            )  # noqa: E501

        self._logs_read_timestamp_entity_id = logs_read_timestamp_entity_id

    @property
    def logs_read_timestamp_entity_type(self):
        """Gets the logs_read_timestamp_entity_type of this V1NetworkAgentsLogsReadsTimestampSearchRequest.  # noqa: E501


        :return: The logs_read_timestamp_entity_type of this V1NetworkAgentsLogsReadsTimestampSearchRequest.  # noqa: E501
        :rtype: LogsReadTimestampEntityType
        """
        return self._logs_read_timestamp_entity_type

    @logs_read_timestamp_entity_type.setter
    def logs_read_timestamp_entity_type(self, logs_read_timestamp_entity_type):
        """Sets the logs_read_timestamp_entity_type of this V1NetworkAgentsLogsReadsTimestampSearchRequest.


        :param logs_read_timestamp_entity_type: The logs_read_timestamp_entity_type of this V1NetworkAgentsLogsReadsTimestampSearchRequest.  # noqa: E501
        :type: LogsReadTimestampEntityType
        """
        if logs_read_timestamp_entity_type is None:
            raise ValueError(
                "Invalid value for `logs_read_timestamp_entity_type`, must not be `None`"
            )  # noqa: E501

        self._logs_read_timestamp_entity_type = logs_read_timestamp_entity_type

    @property
    def logs_read_timestamp_last_read_timestamp(self):
        """Gets the logs_read_timestamp_last_read_timestamp of this V1NetworkAgentsLogsReadsTimestampSearchRequest.  # noqa: E501


        :return: The logs_read_timestamp_last_read_timestamp of this V1NetworkAgentsLogsReadsTimestampSearchRequest.  # noqa: E501
        :rtype: DefaultString
        """
        return self._logs_read_timestamp_last_read_timestamp

    @logs_read_timestamp_last_read_timestamp.setter
    def logs_read_timestamp_last_read_timestamp(
        self, logs_read_timestamp_last_read_timestamp
    ):
        """Sets the logs_read_timestamp_last_read_timestamp of this V1NetworkAgentsLogsReadsTimestampSearchRequest.


        :param logs_read_timestamp_last_read_timestamp: The logs_read_timestamp_last_read_timestamp of this V1NetworkAgentsLogsReadsTimestampSearchRequest.  # noqa: E501
        :type: DefaultString
        """
        if logs_read_timestamp_last_read_timestamp is None:
            raise ValueError(
                "Invalid value for `logs_read_timestamp_last_read_timestamp`, must not be `None`"
            )  # noqa: E501

        self._logs_read_timestamp_last_read_timestamp = (
            logs_read_timestamp_last_read_timestamp
        )

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1NetworkAgentsLogsReadsTimestampSearchRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1NetworkAgentsLogsReadsTimestampSearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class V1NetworkAgentsLogsSearchRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "message": "str",
        "agent_id": "list[int]",
        "severity": "list[V1AgentLogSeverity]",
        "range_from": "datetime",
        "range_to": "datetime",
        "sort": "V1AgentLogSort",
        "_from": "int",
        "size": "int",
    }

    attribute_map = {
        "message": "message",
        "agent_id": "agent_id",
        "severity": "severity",
        "range_from": "range_from",
        "range_to": "range_to",
        "sort": "sort",
        "_from": "from",
        "size": "size",
    }

    def __init__(
        self,
        message=None,
        agent_id=None,
        severity=None,
        range_from=None,
        range_to=None,
        sort=None,
        _from=None,
        size=None,
    ):  # noqa: E501
        """V1NetworkAgentsLogsSearchRequest - a model defined in Swagger"""  # noqa: E501
        self._message = None
        self._agent_id = None
        self._severity = None
        self._range_from = None
        self._range_to = None
        self._sort = None
        self.__from = None
        self._size = None
        self.discriminator = None
        if message is not None:
            self.message = message
        if agent_id is not None:
            self.agent_id = agent_id
        if severity is not None:
            self.severity = severity
        self.range_from = range_from
        self.range_to = range_to
        self.sort = sort
        if _from is not None:
            self._from = _from
        if size is not None:
            self.size = size

    @property
    def message(self):
        """Gets the message of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501


        :return: The message of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this V1NetworkAgentsLogsSearchRequest.


        :param message: The message of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def agent_id(self):
        """Gets the agent_id of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501


        :return: The agent_id of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :rtype: list[int]
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """Sets the agent_id of this V1NetworkAgentsLogsSearchRequest.


        :param agent_id: The agent_id of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :type: list[int]
        """

        self._agent_id = agent_id

    @property
    def severity(self):
        """Gets the severity of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501


        :return: The severity of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :rtype: list[V1AgentLogSeverity]
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this V1NetworkAgentsLogsSearchRequest.


        :param severity: The severity of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :type: list[V1AgentLogSeverity]
        """

        self._severity = severity

    @property
    def range_from(self):
        """Gets the range_from of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501


        :return: The range_from of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._range_from

    @range_from.setter
    def range_from(self, range_from):
        """Sets the range_from of this V1NetworkAgentsLogsSearchRequest.


        :param range_from: The range_from of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :type: datetime
        """
        if range_from is None:
            raise ValueError(
                "Invalid value for `range_from`, must not be `None`"
            )  # noqa: E501

        self._range_from = range_from

    @property
    def range_to(self):
        """Gets the range_to of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501


        :return: The range_to of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._range_to

    @range_to.setter
    def range_to(self, range_to):
        """Sets the range_to of this V1NetworkAgentsLogsSearchRequest.


        :param range_to: The range_to of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :type: datetime
        """
        if range_to is None:
            raise ValueError(
                "Invalid value for `range_to`, must not be `None`"
            )  # noqa: E501

        self._range_to = range_to

    @property
    def sort(self):
        """Gets the sort of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501


        :return: The sort of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :rtype: V1AgentLogSort
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this V1NetworkAgentsLogsSearchRequest.


        :param sort: The sort of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :type: V1AgentLogSort
        """
        if sort is None:
            raise ValueError(
                "Invalid value for `sort`, must not be `None`"
            )  # noqa: E501

        self._sort = sort

    @property
    def _from(self):
        """Gets the _from of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501

        Default: 0  # noqa: E501

        :return: The _from of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this V1NetworkAgentsLogsSearchRequest.

        Default: 0  # noqa: E501

        :param _from: The _from of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :type: int
        """

        self.__from = _from

    @property
    def size(self):
        """Gets the size of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501

        Default: 50  # noqa: E501

        :return: The size of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this V1NetworkAgentsLogsSearchRequest.

        Default: 50  # noqa: E501

        :param size: The size of this V1NetworkAgentsLogsSearchRequest.  # noqa: E501
        :type: int
        """

        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1NetworkAgentsLogsSearchRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1NetworkAgentsLogsSearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class User(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "user_email": "str",
        "user_password": "str",
        "user_id": "float",
        "user_created_at": "datetime",
        "user_updated_at": "datetime",
        "user_settings": "UserSettings",
        "workspace_default_id": "float",
        "permissions": "list[Permission]",
        "user_workspaces": "list[UserWorkspace]",
        "role": "Role",
        "default_workspace": "Workspace",
    }

    attribute_map = {
        "user_email": "user_email",
        "user_password": "user_password",
        "user_id": "user_id",
        "user_created_at": "user_created_at",
        "user_updated_at": "user_updated_at",
        "user_settings": "user_settings",
        "workspace_default_id": "workspace_default_id",
        "permissions": "permissions",
        "user_workspaces": "user_workspaces",
        "role": "role",
        "default_workspace": "default_workspace",
    }

    def __init__(
        self,
        user_email=None,
        user_password=None,
        user_id=None,
        user_created_at=None,
        user_updated_at=None,
        user_settings=None,
        workspace_default_id=None,
        permissions=None,
        user_workspaces=None,
        role=None,
        default_workspace=None,
    ):  # noqa: E501
        """User - a model defined in Swagger"""  # noqa: E501
        self._user_email = None
        self._user_password = None
        self._user_id = None
        self._user_created_at = None
        self._user_updated_at = None
        self._user_settings = None
        self._workspace_default_id = None
        self._permissions = None
        self._user_workspaces = None
        self._role = None
        self._default_workspace = None
        self.discriminator = None
        self.user_email = user_email
        self.user_password = user_password
        self.user_id = user_id
        self.user_created_at = user_created_at
        self.user_updated_at = user_updated_at
        self.user_settings = user_settings
        if workspace_default_id is not None:
            self.workspace_default_id = workspace_default_id
        if permissions is not None:
            self.permissions = permissions
        self.user_workspaces = user_workspaces
        if role is not None:
            self.role = role
        self.default_workspace = default_workspace

    @property
    def user_email(self):
        """Gets the user_email of this User.  # noqa: E501


        :return: The user_email of this User.  # noqa: E501
        :rtype: str
        """
        return self._user_email

    @user_email.setter
    def user_email(self, user_email):
        """Sets the user_email of this User.


        :param user_email: The user_email of this User.  # noqa: E501
        :type: str
        """
        if user_email is None:
            raise ValueError(
                "Invalid value for `user_email`, must not be `None`"
            )  # noqa: E501

        self._user_email = user_email

    @property
    def user_password(self):
        """Gets the user_password of this User.  # noqa: E501


        :return: The user_password of this User.  # noqa: E501
        :rtype: str
        """
        return self._user_password

    @user_password.setter
    def user_password(self, user_password):
        """Sets the user_password of this User.


        :param user_password: The user_password of this User.  # noqa: E501
        :type: str
        """
        if user_password is None:
            raise ValueError(
                "Invalid value for `user_password`, must not be `None`"
            )  # noqa: E501

        self._user_password = user_password

    @property
    def user_id(self):
        """Gets the user_id of this User.  # noqa: E501


        :return: The user_id of this User.  # noqa: E501
        :rtype: float
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this User.


        :param user_id: The user_id of this User.  # noqa: E501
        :type: float
        """
        if user_id is None:
            raise ValueError(
                "Invalid value for `user_id`, must not be `None`"
            )  # noqa: E501

        self._user_id = user_id

    @property
    def user_created_at(self):
        """Gets the user_created_at of this User.  # noqa: E501


        :return: The user_created_at of this User.  # noqa: E501
        :rtype: datetime
        """
        return self._user_created_at

    @user_created_at.setter
    def user_created_at(self, user_created_at):
        """Sets the user_created_at of this User.


        :param user_created_at: The user_created_at of this User.  # noqa: E501
        :type: datetime
        """
        if user_created_at is None:
            raise ValueError(
                "Invalid value for `user_created_at`, must not be `None`"
            )  # noqa: E501

        self._user_created_at = user_created_at

    @property
    def user_updated_at(self):
        """Gets the user_updated_at of this User.  # noqa: E501


        :return: The user_updated_at of this User.  # noqa: E501
        :rtype: datetime
        """
        return self._user_updated_at

    @user_updated_at.setter
    def user_updated_at(self, user_updated_at):
        """Sets the user_updated_at of this User.


        :param user_updated_at: The user_updated_at of this User.  # noqa: E501
        :type: datetime
        """
        if user_updated_at is None:
            raise ValueError(
                "Invalid value for `user_updated_at`, must not be `None`"
            )  # noqa: E501

        self._user_updated_at = user_updated_at

    @property
    def user_settings(self):
        """Gets the user_settings of this User.  # noqa: E501


        :return: The user_settings of this User.  # noqa: E501
        :rtype: UserSettings
        """
        return self._user_settings

    @user_settings.setter
    def user_settings(self, user_settings):
        """Sets the user_settings of this User.


        :param user_settings: The user_settings of this User.  # noqa: E501
        :type: UserSettings
        """
        if user_settings is None:
            raise ValueError(
                "Invalid value for `user_settings`, must not be `None`"
            )  # noqa: E501

        self._user_settings = user_settings

    @property
    def workspace_default_id(self):
        """Gets the workspace_default_id of this User.  # noqa: E501


        :return: The workspace_default_id of this User.  # noqa: E501
        :rtype: float
        """
        return self._workspace_default_id

    @workspace_default_id.setter
    def workspace_default_id(self, workspace_default_id):
        """Sets the workspace_default_id of this User.


        :param workspace_default_id: The workspace_default_id of this User.  # noqa: E501
        :type: float
        """

        self._workspace_default_id = workspace_default_id

    @property
    def permissions(self):
        """Gets the permissions of this User.  # noqa: E501


        :return: The permissions of this User.  # noqa: E501
        :rtype: list[Permission]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this User.


        :param permissions: The permissions of this User.  # noqa: E501
        :type: list[Permission]
        """

        self._permissions = permissions

    @property
    def user_workspaces(self):
        """Gets the user_workspaces of this User.  # noqa: E501


        :return: The user_workspaces of this User.  # noqa: E501
        :rtype: list[UserWorkspace]
        """
        return self._user_workspaces

    @user_workspaces.setter
    def user_workspaces(self, user_workspaces):
        """Sets the user_workspaces of this User.


        :param user_workspaces: The user_workspaces of this User.  # noqa: E501
        :type: list[UserWorkspace]
        """
        if user_workspaces is None:
            raise ValueError(
                "Invalid value for `user_workspaces`, must not be `None`"
            )  # noqa: E501

        self._user_workspaces = user_workspaces

    @property
    def role(self):
        """Gets the role of this User.  # noqa: E501


        :return: The role of this User.  # noqa: E501
        :rtype: Role
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this User.


        :param role: The role of this User.  # noqa: E501
        :type: Role
        """

        self._role = role

    @property
    def default_workspace(self):
        """Gets the default_workspace of this User.  # noqa: E501


        :return: The default_workspace of this User.  # noqa: E501
        :rtype: Workspace
        """
        return self._default_workspace

    @default_workspace.setter
    def default_workspace(self, default_workspace):
        """Sets the default_workspace of this User.


        :param default_workspace: The default_workspace of this User.  # noqa: E501
        :type: Workspace
        """
        if default_workspace is None:
            raise ValueError(
                "Invalid value for `default_workspace`, must not be `None`"
            )  # noqa: E501

        self._default_workspace = default_workspace

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(User, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, User):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Workspace(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "workspace_name": "WorkspaceName",
        "workspace_id": "int",
        "workspace_created_at": "datetime",
        "workspace_require_2fa": "bool",
        "workspace_enable_sdn_connections": "bool",
    }

    attribute_map = {
        "workspace_name": "workspace_name",
        "workspace_id": "workspace_id",
        "workspace_created_at": "workspace_created_at",
        "workspace_require_2fa": "workspace_require_2fa",
        "workspace_enable_sdn_connections": "workspace_enable_sdn_connections",
    }

    def __init__(
        self,
        workspace_name=None,
        workspace_id=None,
        workspace_created_at=None,
        workspace_require_2fa=None,
        workspace_enable_sdn_connections=None,
    ):  # noqa: E501
        """Workspace - a model defined in Swagger"""  # noqa: E501
        self._workspace_name = None
        self._workspace_id = None
        self._workspace_created_at = None
        self._workspace_require_2fa = None
        self._workspace_enable_sdn_connections = None
        self.discriminator = None
        self.workspace_name = workspace_name
        self.workspace_id = workspace_id
        self.workspace_created_at = workspace_created_at
        self.workspace_require_2fa = workspace_require_2fa
        self.workspace_enable_sdn_connections = workspace_enable_sdn_connections

    @property
    def workspace_name(self):
        """Gets the workspace_name of this Workspace.  # noqa: E501


        :return: The workspace_name of this Workspace.  # noqa: E501
        :rtype: WorkspaceName
        """
        return self._workspace_name

    @workspace_name.setter
    def workspace_name(self, workspace_name):
        """Sets the workspace_name of this Workspace.


        :param workspace_name: The workspace_name of this Workspace.  # noqa: E501
        :type: WorkspaceName
        """
        if workspace_name is None:
            raise ValueError(
                "Invalid value for `workspace_name`, must not be `None`"
            )  # noqa: E501

        self._workspace_name = workspace_name

    @property
    def workspace_id(self):
        """Gets the workspace_id of this Workspace.  # noqa: E501


        :return: The workspace_id of this Workspace.  # noqa: E501
        :rtype: int
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this Workspace.


        :param workspace_id: The workspace_id of this Workspace.  # noqa: E501
        :type: int
        """
        if workspace_id is None:
            raise ValueError(
                "Invalid value for `workspace_id`, must not be `None`"
            )  # noqa: E501

        self._workspace_id = workspace_id

    @property
    def workspace_created_at(self):
        """Gets the workspace_created_at of this Workspace.  # noqa: E501


        :return: The workspace_created_at of this Workspace.  # noqa: E501
        :rtype: datetime
        """
        return self._workspace_created_at

    @workspace_created_at.setter
    def workspace_created_at(self, workspace_created_at):
        """Sets the workspace_created_at of this Workspace.


        :param workspace_created_at: The workspace_created_at of this Workspace.  # noqa: E501
        :type: datetime
        """
        if workspace_created_at is None:
            raise ValueError(
                "Invalid value for `workspace_created_at`, must not be `None`"
            )  # noqa: E501

        self._workspace_created_at = workspace_created_at

    @property
    def workspace_require_2fa(self):
        """Gets the workspace_require_2fa of this Workspace.  # noqa: E501


        :return: The workspace_require_2fa of this Workspace.  # noqa: E501
        :rtype: bool
        """
        return self._workspace_require_2fa

    @workspace_require_2fa.setter
    def workspace_require_2fa(self, workspace_require_2fa):
        """Sets the workspace_require_2fa of this Workspace.


        :param workspace_require_2fa: The workspace_require_2fa of this Workspace.  # noqa: E501
        :type: bool
        """
        if workspace_require_2fa is None:
            raise ValueError(
                "Invalid value for `workspace_require_2fa`, must not be `None`"
            )  # noqa: E501

        self._workspace_require_2fa = workspace_require_2fa

    @property
    def workspace_enable_sdn_connections(self):
        """Gets the workspace_enable_sdn_connections of this Workspace.  # noqa: E501


        :return: The workspace_enable_sdn_connections of this Workspace.  # noqa: E501
        :rtype: bool
        """
        return self._workspace_enable_sdn_connections

    @workspace_enable_sdn_connections.setter
    def workspace_enable_sdn_connections(self, workspace_enable_sdn_connections):
        """Sets the workspace_enable_sdn_connections of this Workspace.


        :param workspace_enable_sdn_connections: The workspace_enable_sdn_connections of this Workspace.  # noqa: E501
        :type: bool
        """
        if workspace_enable_sdn_connections is None:
            raise ValueError(
                "Invalid value for `workspace_enable_sdn_connections`, must not be `None`"
            )  # noqa: E501

        self._workspace_enable_sdn_connections = workspace_enable_sdn_connections

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Workspace, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Workspace):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# import apis into api package
from syntropy_sdk.api.agents_api import AgentsApi
from syntropy_sdk.api.analytics_api import AnalyticsApi
from syntropy_sdk.api.audit_api import AuditApi
from syntropy_sdk.api.auth_api import AuthApi
from syntropy_sdk.api.connections_api import ConnectionsApi
from syntropy_sdk.api.network_api import NetworkApi
from syntropy_sdk.api.notification_api import NotificationApi
from syntropy_sdk.api.rules_api import RulesApi
from syntropy_sdk.api.sdn_agents_api import SDNAgentsApi

# flake8: noqa



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from syntropy_sdk.api_client import ApiClient


class AgentsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def v1_network_agents_coordinates_search(self, body, **kwargs):  # noqa: E501
        """Search Agent location coordinates  # noqa: E501

        Retrieves Agents location coordinates.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_coordinates_search(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CoordinatesSearchBody body: (required)
        :return: V1NetworkAgentsCoordinatesSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_coordinates_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_coordinates_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_coordinates_search_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Search Agent location coordinates  # noqa: E501

        Retrieves Agents location coordinates.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_coordinates_search_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CoordinatesSearchBody body: (required)
        :return: V1NetworkAgentsCoordinatesSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_coordinates_search" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_agents_coordinates_search`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/coordinates/search",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAgentsCoordinatesSearchResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_create(self, body, **kwargs):  # noqa: E501
        """Create Agent  # noqa: E501

        Creates new agent. Only `VIRTUAL` agents creation is supported. Not `VIRTUAL` agents are automatically created when first WebSocket connection is established.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_create(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsCreateRequest body: (required)
        :return: V1NetworkAgentsCreateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_create_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_create_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_create_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create Agent  # noqa: E501

        Creates new agent. Only `VIRTUAL` agents creation is supported. Not `VIRTUAL` agents are automatically created when first WebSocket connection is established.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_create_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsCreateRequest body: (required)
        :return: V1NetworkAgentsCreateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_create" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_agents_create`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAgentsCreateResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_delete(self, agent_id, **kwargs):  # noqa: E501
        """Delete Agent  # noqa: E501

        Deletes Agent with existing connections. Learn more about platform agents [here](https://docs.syntropystack.com/docs/what-is-syntropy-agent).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_delete(agent_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdNumber agent_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_delete_with_http_info(
                agent_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_delete_with_http_info(
                agent_id, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_delete_with_http_info(self, agent_id, **kwargs):  # noqa: E501
        """Delete Agent  # noqa: E501

        Deletes Agent with existing connections. Learn more about platform agents [here](https://docs.syntropystack.com/docs/what-is-syntropy-agent).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_delete_with_http_info(agent_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdNumber agent_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["agent_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_delete" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'agent_id' is set
        if "agent_id" not in params or params["agent_id"] is None:
            raise ValueError(
                "Missing the required parameter `agent_id` when calling `v1_network_agents_delete`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "agent_id" in params:
            path_params["agent_id"] = params["agent_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/{agent_id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_filters_search(self, body, **kwargs):  # noqa: E501
        """Search Agent filters  # noqa: E501

        Gets all unique Agents names and ids for filters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_filters_search(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsSearchRequest body: (required)
        :return: V1NetworkAgentsFiltersSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_filters_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_filters_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_filters_search_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Search Agent filters  # noqa: E501

        Gets all unique Agents names and ids for filters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_filters_search_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsSearchRequest body: (required)
        :return: V1NetworkAgentsFiltersSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_filters_search" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_agents_filters_search`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/filters/search",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAgentsFiltersSearchResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_get(self, **kwargs):  # noqa: E501
        """Get Agents  # noqa: E501

        Returns list of Agents.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SkipNumber skip:
        :param TakeNumber take:
        :param WhereString filter: array of agent ids
        :return: V1NetworkAgentsGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.v1_network_agents_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def v1_network_agents_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get Agents  # noqa: E501

        Returns list of Agents.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SkipNumber skip:
        :param TakeNumber take:
        :param WhereString filter: array of agent ids
        :return: V1NetworkAgentsGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["skip", "take", "filter"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_get" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "skip" in params:
            query_params.append(("skip", params["skip"]))  # noqa: E501
        if "take" in params:
            query_params.append(("take", params["take"]))  # noqa: E501
        if "filter" in params:
            query_params.append(("filter", params["filter"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAgentsGetResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_logs_errors_search(self, body, **kwargs):  # noqa: E501
        """Search Agent error logs  # noqa: E501

        Returns a list of Agent error logs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_logs_errors_search(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsLogsErrorsSearchRequest body: (required)
        :return: V1NetworkAgentsLogsErrorsSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_logs_errors_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_logs_errors_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_logs_errors_search_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Search Agent error logs  # noqa: E501

        Returns a list of Agent error logs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_logs_errors_search_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsLogsErrorsSearchRequest body: (required)
        :return: V1NetworkAgentsLogsErrorsSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_logs_errors_search" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_agents_logs_errors_search`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/logs/errors/search",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAgentsLogsErrorsSearchResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_logs_reads_timestamp_search(
        self, body, **kwargs
    ):  # noqa: E501
        """Save log read timestamp  # noqa: E501

        Saves last logs read timestamp.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_logs_reads_timestamp_search(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[V1NetworkAgentsLogsReadsTimestampSearchRequest] body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_logs_reads_timestamp_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_logs_reads_timestamp_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_logs_reads_timestamp_search_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Save log read timestamp  # noqa: E501

        Saves last logs read timestamp.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_logs_reads_timestamp_search_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[V1NetworkAgentsLogsReadsTimestampSearchRequest] body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_logs_reads_timestamp_search" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_agents_logs_reads_timestamp_search`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/logs-reads-timestamp",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_logs_search(self, body, **kwargs):  # noqa: E501
        """Search Agent logs  # noqa: E501

        Search Agent logs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_logs_search(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsLogsSearchRequest body: (required)
        :return: V1NetworkAgentsLogsSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_logs_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_logs_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_logs_search_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Search Agent logs  # noqa: E501

        Search Agent logs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_logs_search_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsLogsSearchRequest body: (required)
        :return: V1NetworkAgentsLogsSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_logs_search" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_agents_logs_search`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/logs/search",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAgentsLogsSearchResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_providers_get(self, **kwargs):  # noqa: E501
        """Get Agent providers  # noqa: E501

        Returns list of Agent providers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_providers_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SkipNumber skip:
        :param TakeNumber take:
        :param AgentProviderOrderString order:
        :param WhereString filter: array of agent provider ids
        :return: V1NetworkAgentsProvidersGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_providers_get_with_http_info(
                **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_providers_get_with_http_info(
                **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_providers_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get Agent providers  # noqa: E501

        Returns list of Agent providers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_providers_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SkipNumber skip:
        :param TakeNumber take:
        :param AgentProviderOrderString order:
        :param WhereString filter: array of agent provider ids
        :return: V1NetworkAgentsProvidersGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["skip", "take", "order", "filter"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_providers_get" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "skip" in params:
            query_params.append(("skip", params["skip"]))  # noqa: E501
        if "take" in params:
            query_params.append(("take", params["take"]))  # noqa: E501
        if "order" in params:
            query_params.append(("order", params["order"]))  # noqa: E501
        if "filter" in params:
            query_params.append(("filter", params["filter"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/providers",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAgentsProvidersGetResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_remove(self, body, **kwargs):  # noqa: E501
        """Delete Agents  # noqa: E501

        Deletes Agents with existing connections. Learn more about platform agents [here](https://docs.syntropystack.com/docs/what-is-syntropy-agent).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_remove(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsRemoveRequest body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_remove_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_remove_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_remove_with_http_info(self, body, **kwargs):  # noqa: E501
        """Delete Agents  # noqa: E501

        Deletes Agents with existing connections. Learn more about platform agents [here](https://docs.syntropystack.com/docs/what-is-syntropy-agent).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_remove_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsRemoveRequest body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_remove" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_agents_remove`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/remove",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_search(self, body, **kwargs):  # noqa: E501
        """Search Agents  # noqa: E501

        Return a list of agents. Learn more about platform agents [here](https://docs.syntropystack.com/docs/what-is-syntropy-agent).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_search(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsSearchRequest body: (required)
        :return: V1NetworkAgentsSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_search_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_search_with_http_info(self, body, **kwargs):  # noqa: E501
        """Search Agents  # noqa: E501

        Return a list of agents. Learn more about platform agents [here](https://docs.syntropystack.com/docs/what-is-syntropy-agent).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_search_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsSearchRequest body: (required)
        :return: V1NetworkAgentsSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_search" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_agents_search`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/search",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAgentsSearchResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_services_delete(
        self, agent_service_subnet_id, **kwargs
    ):  # noqa: E501
        """Delete Agent service  # noqa: E501

        Deletes Agent service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_services_delete(agent_service_subnet_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdNumber agent_service_subnet_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_services_delete_with_http_info(
                agent_service_subnet_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_services_delete_with_http_info(
                agent_service_subnet_id, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_services_delete_with_http_info(
        self, agent_service_subnet_id, **kwargs
    ):  # noqa: E501
        """Delete Agent service  # noqa: E501

        Deletes Agent service.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_services_delete_with_http_info(agent_service_subnet_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdNumber agent_service_subnet_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["agent_service_subnet_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_services_delete" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'agent_service_subnet_id' is set
        if (
            "agent_service_subnet_id" not in params
            or params["agent_service_subnet_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `agent_service_subnet_id` when calling `v1_network_agents_services_delete`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "agent_service_subnet_id" in params:
            path_params["agent_service_subnet_id"] = params[
                "agent_service_subnet_id"
            ]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/services/{agent_service_subnet_id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_services_get(self, **kwargs):  # noqa: E501
        """Get Agent services.  # noqa: E501

        Returns list of Agent services  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_services_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param WhereString filter: array of agent ids
        :return: V1NetworkAgentsServicesGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_services_get_with_http_info(
                **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_services_get_with_http_info(
                **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_services_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get Agent services.  # noqa: E501

        Returns list of Agent services  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_services_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param WhereString filter: array of agent ids
        :return: V1NetworkAgentsServicesGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["filter"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_services_get" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "filter" in params:
            query_params.append(("filter", params["filter"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/services",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAgentsServicesGetResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_services_remove(self, body, **kwargs):  # noqa: E501
        """Delete Agent services  # noqa: E501

        Deletes Agent services.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_services_remove(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsServicesRemoveRequest body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_services_remove_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_services_remove_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_services_remove_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Delete Agent services  # noqa: E501

        Deletes Agent services.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_services_remove_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsServicesRemoveRequest body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_services_remove" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_agents_services_remove`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/services/remove",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_services_update(self, body, **kwargs):  # noqa: E501
        """Update Agent services  # noqa: E501

        Updates Agent services.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_services_update(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsServicesUpdateRequest body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_services_update_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_services_update_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_services_update_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Update Agent services  # noqa: E501

        Updates Agent services.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_services_update_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsServicesUpdateRequest body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_services_update" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_agents_services_update`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/services/bulk",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_settings_get(self, **kwargs):  # noqa: E501
        """Get Agent settings  # noqa: E501

        Gets Agents settings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_settings_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: V1NetworkAgentsSettingsGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_settings_get_with_http_info(
                **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_settings_get_with_http_info(
                **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_settings_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get Agent settings  # noqa: E501

        Gets Agents settings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_settings_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: V1NetworkAgentsSettingsGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_settings_get" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/settings",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAgentsSettingsGetResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_settings_update(self, body, **kwargs):  # noqa: E501
        """Update Agent settings  # noqa: E501

        Updates Agents settings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_settings_update(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsSettingsUpdateRequest body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_settings_update_with_http_info(
                body, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_settings_update_with_http_info(
                body, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_settings_update_with_http_info(
        self, body, **kwargs
    ):  # noqa: E501
        """Update Agent settings  # noqa: E501

        Updates Agents settings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_settings_update_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsSettingsUpdateRequest body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_settings_update" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_agents_settings_update`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/settings",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_tags_get(self, **kwargs):  # noqa: E501
        """Get Agent tags  # noqa: E501

        Returns a list of user Agent tags.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_tags_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: V1NetworkAgentsTagsGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_tags_get_with_http_info(
                **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_tags_get_with_http_info(
                **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_tags_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get Agent tags  # noqa: E501

        Returns a list of user Agent tags.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_tags_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: V1NetworkAgentsTagsGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_tags_get" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/tags",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAgentsTagsGetResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_update(self, body, agent_id, **kwargs):  # noqa: E501
        """Updates Agent  # noqa: E501

        Update Agent.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_update(body, agent_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsUpdateRequest body: (required)
        :param IdNumber agent_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_update_with_http_info(
                body, agent_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_update_with_http_info(
                body, agent_id, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_update_with_http_info(
        self, body, agent_id, **kwargs
    ):  # noqa: E501
        """Updates Agent  # noqa: E501

        Update Agent.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_update_with_http_info(body, agent_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1NetworkAgentsUpdateRequest body: (required)
        :param IdNumber agent_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["body", "agent_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_update" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `v1_network_agents_update`"
            )  # noqa: E501
        # verify the required parameter 'agent_id' is set
        if "agent_id" not in params or params["agent_id"] is None:
            raise ValueError(
                "Missing the required parameter `agent_id` when calling `v1_network_agents_update`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "agent_id" in params:
            path_params["agent_id"] = params["agent_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/{agent_id}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def v1_network_agents_wg_config_get_one(self, agent_id, **kwargs):  # noqa: E501
        """Get Agent Wg config  # noqa: E501

        Returns Agents WireGuard configuration.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_wg_config_get_one(agent_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdNumber agent_id: (required)
        :return: V1NetworkAgentsWgConfigGetOneResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.v1_network_agents_wg_config_get_one_with_http_info(
                agent_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.v1_network_agents_wg_config_get_one_with_http_info(
                agent_id, **kwargs
            )  # noqa: E501
            return data

    def v1_network_agents_wg_config_get_one_with_http_info(
        self, agent_id, **kwargs
    ):  # noqa: E501
        """Get Agent Wg config  # noqa: E501

        Returns Agents WireGuard configuration.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.v1_network_agents_wg_config_get_one_with_http_info(agent_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdNumber agent_id: (required)
        :return: V1NetworkAgentsWgConfigGetOneResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["agent_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method v1_network_agents_wg_config_get_one" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'agent_id' is set
        if "agent_id" not in params or params["agent_id"] is None:
            raise ValueError(
                "Missing the required parameter `agent_id` when calling `v1_network_agents_wg_config_get_one`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "agent_id" in params:
            path_params["agent_id"] = params["agent_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["jwt"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/network/agents/wg-config/{agent_id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="V1NetworkAgentsWgConfigGetOneResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class V1AStatusAgentStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "iface_active": "str",
        "public_last_handshake": "str",
        "public_latency": "float",
        "public_packet_loss": "float",
        "public_status": "str",
        "public_warnings": "list[str]",
        "sdn1_last_handshake": "str",
        "sdn1_latency": "float",
        "sdn1_packet_loss": "float",
        "sdn1_path": "list[int]",
        "sdn1_status": "str",
        "sdn1_warnings": "list[str]",
        "sdn2_last_handshake": "str",
        "sdn2_latency": "float",
        "sdn2_packet_loss": "float",
        "sdn2_path": "list[int]",
        "sdn2_status": "str",
        "sdn2_warnings": "list[str]",
        "sdn3_last_handshake": "str",
        "sdn3_latency": "float",
        "sdn3_packet_loss": "float",
        "sdn3_path": "list[int]",
        "sdn3_status": "str",
        "sdn3_warnings": "list[str]",
        "status": "str",
        "updated_at": "str",
    }

    attribute_map = {
        "iface_active": "iface_active",
        "public_last_handshake": "public_last_handshake",
        "public_latency": "public_latency",
        "public_packet_loss": "public_packet_loss",
        "public_status": "public_status",
        "public_warnings": "public_warnings",
        "sdn1_last_handshake": "sdn1_last_handshake",
        "sdn1_latency": "sdn1_latency",
        "sdn1_packet_loss": "sdn1_packet_loss",
        "sdn1_path": "sdn1_path",
        "sdn1_status": "sdn1_status",
        "sdn1_warnings": "sdn1_warnings",
        "sdn2_last_handshake": "sdn2_last_handshake",
        "sdn2_latency": "sdn2_latency",
        "sdn2_packet_loss": "sdn2_packet_loss",
        "sdn2_path": "sdn2_path",
        "sdn2_status": "sdn2_status",
        "sdn2_warnings": "sdn2_warnings",
        "sdn3_last_handshake": "sdn3_last_handshake",
        "sdn3_latency": "sdn3_latency",
        "sdn3_packet_loss": "sdn3_packet_loss",
        "sdn3_path": "sdn3_path",
        "sdn3_status": "sdn3_status",
        "sdn3_warnings": "sdn3_warnings",
        "status": "status",
        "updated_at": "updated_at",
    }

    def __init__(
        self,
        iface_active=None,
        public_last_handshake=None,
        public_latency=None,
        public_packet_loss=None,
        public_status=None,
        public_warnings=None,
        sdn1_last_handshake=None,
        sdn1_latency=None,
        sdn1_packet_loss=None,
        sdn1_path=None,
        sdn1_status=None,
        sdn1_warnings=None,
        sdn2_last_handshake=None,
        sdn2_latency=None,
        sdn2_packet_loss=None,
        sdn2_path=None,
        sdn2_status=None,
        sdn2_warnings=None,
        sdn3_last_handshake=None,
        sdn3_latency=None,
        sdn3_packet_loss=None,
        sdn3_path=None,
        sdn3_status=None,
        sdn3_warnings=None,
        status=None,
        updated_at=None,
    ):  # noqa: E501
        """V1AStatusAgentStatus - a model defined in Swagger"""  # noqa: E501
        self._iface_active = None
        self._public_last_handshake = None
        self._public_latency = None
        self._public_packet_loss = None
        self._public_status = None
        self._public_warnings = None
        self._sdn1_last_handshake = None
        self._sdn1_latency = None
        self._sdn1_packet_loss = None
        self._sdn1_path = None
        self._sdn1_status = None
        self._sdn1_warnings = None
        self._sdn2_last_handshake = None
        self._sdn2_latency = None
        self._sdn2_packet_loss = None
        self._sdn2_path = None
        self._sdn2_status = None
        self._sdn2_warnings = None
        self._sdn3_last_handshake = None
        self._sdn3_latency = None
        self._sdn3_packet_loss = None
        self._sdn3_path = None
        self._sdn3_status = None
        self._sdn3_warnings = None
        self._status = None
        self._updated_at = None
        self.discriminator = None
        self.iface_active = iface_active
        self.public_last_handshake = public_last_handshake
        self.public_latency = public_latency
        self.public_packet_loss = public_packet_loss
        self.public_status = public_status
        self.public_warnings = public_warnings
        self.sdn1_last_handshake = sdn1_last_handshake
        self.sdn1_latency = sdn1_latency
        self.sdn1_packet_loss = sdn1_packet_loss
        self.sdn1_path = sdn1_path
        self.sdn1_status = sdn1_status
        self.sdn1_warnings = sdn1_warnings
        self.sdn2_last_handshake = sdn2_last_handshake
        self.sdn2_latency = sdn2_latency
        self.sdn2_packet_loss = sdn2_packet_loss
        self.sdn2_path = sdn2_path
        self.sdn2_status = sdn2_status
        self.sdn2_warnings = sdn2_warnings
        self.sdn3_last_handshake = sdn3_last_handshake
        self.sdn3_latency = sdn3_latency
        self.sdn3_packet_loss = sdn3_packet_loss
        self.sdn3_path = sdn3_path
        self.sdn3_status = sdn3_status
        self.sdn3_warnings = sdn3_warnings
        self.status = status
        self.updated_at = updated_at

    @property
    def iface_active(self):
        """Gets the iface_active of this V1AStatusAgentStatus.  # noqa: E501


        :return: The iface_active of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: str
        """
        return self._iface_active

    @iface_active.setter
    def iface_active(self, iface_active):
        """Sets the iface_active of this V1AStatusAgentStatus.


        :param iface_active: The iface_active of this V1AStatusAgentStatus.  # noqa: E501
        :type: str
        """
        if iface_active is None:
            raise ValueError(
                "Invalid value for `iface_active`, must not be `None`"
            )  # noqa: E501

        self._iface_active = iface_active

    @property
    def public_last_handshake(self):
        """Gets the public_last_handshake of this V1AStatusAgentStatus.  # noqa: E501


        :return: The public_last_handshake of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: str
        """
        return self._public_last_handshake

    @public_last_handshake.setter
    def public_last_handshake(self, public_last_handshake):
        """Sets the public_last_handshake of this V1AStatusAgentStatus.


        :param public_last_handshake: The public_last_handshake of this V1AStatusAgentStatus.  # noqa: E501
        :type: str
        """
        if public_last_handshake is None:
            raise ValueError(
                "Invalid value for `public_last_handshake`, must not be `None`"
            )  # noqa: E501

        self._public_last_handshake = public_last_handshake

    @property
    def public_latency(self):
        """Gets the public_latency of this V1AStatusAgentStatus.  # noqa: E501


        :return: The public_latency of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: float
        """
        return self._public_latency

    @public_latency.setter
    def public_latency(self, public_latency):
        """Sets the public_latency of this V1AStatusAgentStatus.


        :param public_latency: The public_latency of this V1AStatusAgentStatus.  # noqa: E501
        :type: float
        """
        if public_latency is None:
            raise ValueError(
                "Invalid value for `public_latency`, must not be `None`"
            )  # noqa: E501

        self._public_latency = public_latency

    @property
    def public_packet_loss(self):
        """Gets the public_packet_loss of this V1AStatusAgentStatus.  # noqa: E501


        :return: The public_packet_loss of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: float
        """
        return self._public_packet_loss

    @public_packet_loss.setter
    def public_packet_loss(self, public_packet_loss):
        """Sets the public_packet_loss of this V1AStatusAgentStatus.


        :param public_packet_loss: The public_packet_loss of this V1AStatusAgentStatus.  # noqa: E501
        :type: float
        """
        if public_packet_loss is None:
            raise ValueError(
                "Invalid value for `public_packet_loss`, must not be `None`"
            )  # noqa: E501

        self._public_packet_loss = public_packet_loss

    @property
    def public_status(self):
        """Gets the public_status of this V1AStatusAgentStatus.  # noqa: E501


        :return: The public_status of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: str
        """
        return self._public_status

    @public_status.setter
    def public_status(self, public_status):
        """Sets the public_status of this V1AStatusAgentStatus.


        :param public_status: The public_status of this V1AStatusAgentStatus.  # noqa: E501
        :type: str
        """
        if public_status is None:
            raise ValueError(
                "Invalid value for `public_status`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["OK", "WARNING", "ERROR"]  # noqa: E501
        if public_status not in allowed_values:
            raise ValueError(
                "Invalid value for `public_status` ({0}), must be one of {1}".format(  # noqa: E501
                    public_status, allowed_values
                )
            )

        self._public_status = public_status

    @property
    def public_warnings(self):
        """Gets the public_warnings of this V1AStatusAgentStatus.  # noqa: E501


        :return: The public_warnings of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._public_warnings

    @public_warnings.setter
    def public_warnings(self, public_warnings):
        """Sets the public_warnings of this V1AStatusAgentStatus.


        :param public_warnings: The public_warnings of this V1AStatusAgentStatus.  # noqa: E501
        :type: list[str]
        """
        if public_warnings is None:
            raise ValueError(
                "Invalid value for `public_warnings`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["PACKET_LOSS", "LATENCY", "HANDSHAKE"]  # noqa: E501
        if not set(public_warnings).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `public_warnings` [{0}], must be a subset of [{1}]".format(  # noqa: E501
                    ", ".join(
                        map(str, set(public_warnings) - set(allowed_values))
                    ),  # noqa: E501
                    ", ".join(map(str, allowed_values)),
                )
            )

        self._public_warnings = public_warnings

    @property
    def sdn1_last_handshake(self):
        """Gets the sdn1_last_handshake of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn1_last_handshake of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: str
        """
        return self._sdn1_last_handshake

    @sdn1_last_handshake.setter
    def sdn1_last_handshake(self, sdn1_last_handshake):
        """Sets the sdn1_last_handshake of this V1AStatusAgentStatus.


        :param sdn1_last_handshake: The sdn1_last_handshake of this V1AStatusAgentStatus.  # noqa: E501
        :type: str
        """
        if sdn1_last_handshake is None:
            raise ValueError(
                "Invalid value for `sdn1_last_handshake`, must not be `None`"
            )  # noqa: E501

        self._sdn1_last_handshake = sdn1_last_handshake

    @property
    def sdn1_latency(self):
        """Gets the sdn1_latency of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn1_latency of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: float
        """
        return self._sdn1_latency

    @sdn1_latency.setter
    def sdn1_latency(self, sdn1_latency):
        """Sets the sdn1_latency of this V1AStatusAgentStatus.


        :param sdn1_latency: The sdn1_latency of this V1AStatusAgentStatus.  # noqa: E501
        :type: float
        """
        if sdn1_latency is None:
            raise ValueError(
                "Invalid value for `sdn1_latency`, must not be `None`"
            )  # noqa: E501

        self._sdn1_latency = sdn1_latency

    @property
    def sdn1_packet_loss(self):
        """Gets the sdn1_packet_loss of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn1_packet_loss of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: float
        """
        return self._sdn1_packet_loss

    @sdn1_packet_loss.setter
    def sdn1_packet_loss(self, sdn1_packet_loss):
        """Sets the sdn1_packet_loss of this V1AStatusAgentStatus.


        :param sdn1_packet_loss: The sdn1_packet_loss of this V1AStatusAgentStatus.  # noqa: E501
        :type: float
        """
        if sdn1_packet_loss is None:
            raise ValueError(
                "Invalid value for `sdn1_packet_loss`, must not be `None`"
            )  # noqa: E501

        self._sdn1_packet_loss = sdn1_packet_loss

    @property
    def sdn1_path(self):
        """Gets the sdn1_path of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn1_path of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: list[int]
        """
        return self._sdn1_path

    @sdn1_path.setter
    def sdn1_path(self, sdn1_path):
        """Sets the sdn1_path of this V1AStatusAgentStatus.


        :param sdn1_path: The sdn1_path of this V1AStatusAgentStatus.  # noqa: E501
        :type: list[int]
        """
        if sdn1_path is None:
            raise ValueError(
                "Invalid value for `sdn1_path`, must not be `None`"
            )  # noqa: E501

        self._sdn1_path = sdn1_path

    @property
    def sdn1_status(self):
        """Gets the sdn1_status of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn1_status of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: str
        """
        return self._sdn1_status

    @sdn1_status.setter
    def sdn1_status(self, sdn1_status):
        """Sets the sdn1_status of this V1AStatusAgentStatus.


        :param sdn1_status: The sdn1_status of this V1AStatusAgentStatus.  # noqa: E501
        :type: str
        """
        if sdn1_status is None:
            raise ValueError(
                "Invalid value for `sdn1_status`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["OK", "WARNING", "ERROR"]  # noqa: E501
        if sdn1_status not in allowed_values:
            raise ValueError(
                "Invalid value for `sdn1_status` ({0}), must be one of {1}".format(  # noqa: E501
                    sdn1_status, allowed_values
                )
            )

        self._sdn1_status = sdn1_status

    @property
    def sdn1_warnings(self):
        """Gets the sdn1_warnings of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn1_warnings of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._sdn1_warnings

    @sdn1_warnings.setter
    def sdn1_warnings(self, sdn1_warnings):
        """Sets the sdn1_warnings of this V1AStatusAgentStatus.


        :param sdn1_warnings: The sdn1_warnings of this V1AStatusAgentStatus.  # noqa: E501
        :type: list[str]
        """
        if sdn1_warnings is None:
            raise ValueError(
                "Invalid value for `sdn1_warnings`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["PACKET_LOSS", "LATENCY", "HANDSHAKE"]  # noqa: E501
        if not set(sdn1_warnings).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `sdn1_warnings` [{0}], must be a subset of [{1}]".format(  # noqa: E501
                    ", ".join(
                        map(str, set(sdn1_warnings) - set(allowed_values))
                    ),  # noqa: E501
                    ", ".join(map(str, allowed_values)),
                )
            )

        self._sdn1_warnings = sdn1_warnings

    @property
    def sdn2_last_handshake(self):
        """Gets the sdn2_last_handshake of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn2_last_handshake of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: str
        """
        return self._sdn2_last_handshake

    @sdn2_last_handshake.setter
    def sdn2_last_handshake(self, sdn2_last_handshake):
        """Sets the sdn2_last_handshake of this V1AStatusAgentStatus.


        :param sdn2_last_handshake: The sdn2_last_handshake of this V1AStatusAgentStatus.  # noqa: E501
        :type: str
        """
        if sdn2_last_handshake is None:
            raise ValueError(
                "Invalid value for `sdn2_last_handshake`, must not be `None`"
            )  # noqa: E501

        self._sdn2_last_handshake = sdn2_last_handshake

    @property
    def sdn2_latency(self):
        """Gets the sdn2_latency of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn2_latency of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: float
        """
        return self._sdn2_latency

    @sdn2_latency.setter
    def sdn2_latency(self, sdn2_latency):
        """Sets the sdn2_latency of this V1AStatusAgentStatus.


        :param sdn2_latency: The sdn2_latency of this V1AStatusAgentStatus.  # noqa: E501
        :type: float
        """
        if sdn2_latency is None:
            raise ValueError(
                "Invalid value for `sdn2_latency`, must not be `None`"
            )  # noqa: E501

        self._sdn2_latency = sdn2_latency

    @property
    def sdn2_packet_loss(self):
        """Gets the sdn2_packet_loss of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn2_packet_loss of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: float
        """
        return self._sdn2_packet_loss

    @sdn2_packet_loss.setter
    def sdn2_packet_loss(self, sdn2_packet_loss):
        """Sets the sdn2_packet_loss of this V1AStatusAgentStatus.


        :param sdn2_packet_loss: The sdn2_packet_loss of this V1AStatusAgentStatus.  # noqa: E501
        :type: float
        """
        if sdn2_packet_loss is None:
            raise ValueError(
                "Invalid value for `sdn2_packet_loss`, must not be `None`"
            )  # noqa: E501

        self._sdn2_packet_loss = sdn2_packet_loss

    @property
    def sdn2_path(self):
        """Gets the sdn2_path of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn2_path of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: list[int]
        """
        return self._sdn2_path

    @sdn2_path.setter
    def sdn2_path(self, sdn2_path):
        """Sets the sdn2_path of this V1AStatusAgentStatus.


        :param sdn2_path: The sdn2_path of this V1AStatusAgentStatus.  # noqa: E501
        :type: list[int]
        """
        if sdn2_path is None:
            raise ValueError(
                "Invalid value for `sdn2_path`, must not be `None`"
            )  # noqa: E501

        self._sdn2_path = sdn2_path

    @property
    def sdn2_status(self):
        """Gets the sdn2_status of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn2_status of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: str
        """
        return self._sdn2_status

    @sdn2_status.setter
    def sdn2_status(self, sdn2_status):
        """Sets the sdn2_status of this V1AStatusAgentStatus.


        :param sdn2_status: The sdn2_status of this V1AStatusAgentStatus.  # noqa: E501
        :type: str
        """
        if sdn2_status is None:
            raise ValueError(
                "Invalid value for `sdn2_status`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["OK", "WARNING", "ERROR"]  # noqa: E501
        if sdn2_status not in allowed_values:
            raise ValueError(
                "Invalid value for `sdn2_status` ({0}), must be one of {1}".format(  # noqa: E501
                    sdn2_status, allowed_values
                )
            )

        self._sdn2_status = sdn2_status

    @property
    def sdn2_warnings(self):
        """Gets the sdn2_warnings of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn2_warnings of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._sdn2_warnings

    @sdn2_warnings.setter
    def sdn2_warnings(self, sdn2_warnings):
        """Sets the sdn2_warnings of this V1AStatusAgentStatus.


        :param sdn2_warnings: The sdn2_warnings of this V1AStatusAgentStatus.  # noqa: E501
        :type: list[str]
        """
        if sdn2_warnings is None:
            raise ValueError(
                "Invalid value for `sdn2_warnings`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["PACKET_LOSS", "LATENCY", "HANDSHAKE"]  # noqa: E501
        if not set(sdn2_warnings).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `sdn2_warnings` [{0}], must be a subset of [{1}]".format(  # noqa: E501
                    ", ".join(
                        map(str, set(sdn2_warnings) - set(allowed_values))
                    ),  # noqa: E501
                    ", ".join(map(str, allowed_values)),
                )
            )

        self._sdn2_warnings = sdn2_warnings

    @property
    def sdn3_last_handshake(self):
        """Gets the sdn3_last_handshake of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn3_last_handshake of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: str
        """
        return self._sdn3_last_handshake

    @sdn3_last_handshake.setter
    def sdn3_last_handshake(self, sdn3_last_handshake):
        """Sets the sdn3_last_handshake of this V1AStatusAgentStatus.


        :param sdn3_last_handshake: The sdn3_last_handshake of this V1AStatusAgentStatus.  # noqa: E501
        :type: str
        """
        if sdn3_last_handshake is None:
            raise ValueError(
                "Invalid value for `sdn3_last_handshake`, must not be `None`"
            )  # noqa: E501

        self._sdn3_last_handshake = sdn3_last_handshake

    @property
    def sdn3_latency(self):
        """Gets the sdn3_latency of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn3_latency of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: float
        """
        return self._sdn3_latency

    @sdn3_latency.setter
    def sdn3_latency(self, sdn3_latency):
        """Sets the sdn3_latency of this V1AStatusAgentStatus.


        :param sdn3_latency: The sdn3_latency of this V1AStatusAgentStatus.  # noqa: E501
        :type: float
        """
        if sdn3_latency is None:
            raise ValueError(
                "Invalid value for `sdn3_latency`, must not be `None`"
            )  # noqa: E501

        self._sdn3_latency = sdn3_latency

    @property
    def sdn3_packet_loss(self):
        """Gets the sdn3_packet_loss of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn3_packet_loss of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: float
        """
        return self._sdn3_packet_loss

    @sdn3_packet_loss.setter
    def sdn3_packet_loss(self, sdn3_packet_loss):
        """Sets the sdn3_packet_loss of this V1AStatusAgentStatus.


        :param sdn3_packet_loss: The sdn3_packet_loss of this V1AStatusAgentStatus.  # noqa: E501
        :type: float
        """
        if sdn3_packet_loss is None:
            raise ValueError(
                "Invalid value for `sdn3_packet_loss`, must not be `None`"
            )  # noqa: E501

        self._sdn3_packet_loss = sdn3_packet_loss

    @property
    def sdn3_path(self):
        """Gets the sdn3_path of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn3_path of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: list[int]
        """
        return self._sdn3_path

    @sdn3_path.setter
    def sdn3_path(self, sdn3_path):
        """Sets the sdn3_path of this V1AStatusAgentStatus.


        :param sdn3_path: The sdn3_path of this V1AStatusAgentStatus.  # noqa: E501
        :type: list[int]
        """
        if sdn3_path is None:
            raise ValueError(
                "Invalid value for `sdn3_path`, must not be `None`"
            )  # noqa: E501

        self._sdn3_path = sdn3_path

    @property
    def sdn3_status(self):
        """Gets the sdn3_status of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn3_status of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: str
        """
        return self._sdn3_status

    @sdn3_status.setter
    def sdn3_status(self, sdn3_status):
        """Sets the sdn3_status of this V1AStatusAgentStatus.


        :param sdn3_status: The sdn3_status of this V1AStatusAgentStatus.  # noqa: E501
        :type: str
        """
        if sdn3_status is None:
            raise ValueError(
                "Invalid value for `sdn3_status`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["OK", "WARNING", "ERROR"]  # noqa: E501
        if sdn3_status not in allowed_values:
            raise ValueError(
                "Invalid value for `sdn3_status` ({0}), must be one of {1}".format(  # noqa: E501
                    sdn3_status, allowed_values
                )
            )

        self._sdn3_status = sdn3_status

    @property
    def sdn3_warnings(self):
        """Gets the sdn3_warnings of this V1AStatusAgentStatus.  # noqa: E501


        :return: The sdn3_warnings of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._sdn3_warnings

    @sdn3_warnings.setter
    def sdn3_warnings(self, sdn3_warnings):
        """Sets the sdn3_warnings of this V1AStatusAgentStatus.


        :param sdn3_warnings: The sdn3_warnings of this V1AStatusAgentStatus.  # noqa: E501
        :type: list[str]
        """
        if sdn3_warnings is None:
            raise ValueError(
                "Invalid value for `sdn3_warnings`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["PACKET_LOSS", "LATENCY", "HANDSHAKE"]  # noqa: E501
        if not set(sdn3_warnings).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `sdn3_warnings` [{0}], must be a subset of [{1}]".format(  # noqa: E501
                    ", ".join(
                        map(str, set(sdn3_warnings) - set(allowed_values))
                    ),  # noqa: E501
                    ", ".join(map(str, allowed_values)),
                )
            )

        self._sdn3_warnings = sdn3_warnings

    @property
    def status(self):
        """Gets the status of this V1AStatusAgentStatus.  # noqa: E501


        :return: The status of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this V1AStatusAgentStatus.


        :param status: The status of this V1AStatusAgentStatus.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError(
                "Invalid value for `status`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["OK", "WARNING", "ERROR"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    @property
    def updated_at(self):
        """Gets the updated_at of this V1AStatusAgentStatus.  # noqa: E501


        :return: The updated_at of this V1AStatusAgentStatus.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this V1AStatusAgentStatus.


        :param updated_at: The updated_at of this V1AStatusAgentStatus.  # noqa: E501
        :type: str
        """
        if updated_at is None:
            raise ValueError(
                "Invalid value for `updated_at`, must not be `None`"
            )  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1AStatusAgentStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1AStatusAgentStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AuditLog(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "action_type": "str",
        "parameters": "str",
        "performed_by": "str",
        "record_type": "str",
        "source_type": "str",
        "timestamp": "str",
        "user_id": "int",
        "workspace_id": "int",
    }

    attribute_map = {
        "action_type": "action_type",
        "parameters": "parameters",
        "performed_by": "performed_by",
        "record_type": "record_type",
        "source_type": "source_type",
        "timestamp": "timestamp",
        "user_id": "user_id",
        "workspace_id": "workspace_id",
    }

    def __init__(
        self,
        action_type=None,
        parameters=None,
        performed_by=None,
        record_type=None,
        source_type=None,
        timestamp=None,
        user_id=None,
        workspace_id=None,
    ):  # noqa: E501
        """AuditLog - a model defined in Swagger"""  # noqa: E501
        self._action_type = None
        self._parameters = None
        self._performed_by = None
        self._record_type = None
        self._source_type = None
        self._timestamp = None
        self._user_id = None
        self._workspace_id = None
        self.discriminator = None
        self.action_type = action_type
        self.parameters = parameters
        self.performed_by = performed_by
        self.record_type = record_type
        self.source_type = source_type
        self.timestamp = timestamp
        self.user_id = user_id
        self.workspace_id = workspace_id

    @property
    def action_type(self):
        """Gets the action_type of this AuditLog.  # noqa: E501


        :return: The action_type of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this AuditLog.


        :param action_type: The action_type of this AuditLog.  # noqa: E501
        :type: str
        """
        if action_type is None:
            raise ValueError(
                "Invalid value for `action_type`, must not be `None`"
            )  # noqa: E501
        allowed_values = [
            "ACTION_CREATED",
            "ACTION_DELETED",
            "ACTION_UPDATED",
        ]  # noqa: E501
        if action_type not in allowed_values:
            raise ValueError(
                "Invalid value for `action_type` ({0}), must be one of {1}".format(  # noqa: E501
                    action_type, allowed_values
                )
            )

        self._action_type = action_type

    @property
    def parameters(self):
        """Gets the parameters of this AuditLog.  # noqa: E501


        :return: The parameters of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this AuditLog.


        :param parameters: The parameters of this AuditLog.  # noqa: E501
        :type: str
        """
        if parameters is None:
            raise ValueError(
                "Invalid value for `parameters`, must not be `None`"
            )  # noqa: E501

        self._parameters = parameters

    @property
    def performed_by(self):
        """Gets the performed_by of this AuditLog.  # noqa: E501


        :return: The performed_by of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._performed_by

    @performed_by.setter
    def performed_by(self, performed_by):
        """Sets the performed_by of this AuditLog.


        :param performed_by: The performed_by of this AuditLog.  # noqa: E501
        :type: str
        """
        if performed_by is None:
            raise ValueError(
                "Invalid value for `performed_by`, must not be `None`"
            )  # noqa: E501

        self._performed_by = performed_by

    @property
    def record_type(self):
        """Gets the record_type of this AuditLog.  # noqa: E501


        :return: The record_type of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._record_type

    @record_type.setter
    def record_type(self, record_type):
        """Sets the record_type of this AuditLog.


        :param record_type: The record_type of this AuditLog.  # noqa: E501
        :type: str
        """
        if record_type is None:
            raise ValueError(
                "Invalid value for `record_type`, must not be `None`"
            )  # noqa: E501
        allowed_values = [
            "TYPE_ACCESS_TOKEN",
            "TYPE_AGENT_TOKEN",
            "TYPE_AGENT",
            "TYPE_CONNECTION",
            "TYPE_SERVICE",
        ]  # noqa: E501
        if record_type not in allowed_values:
            raise ValueError(
                "Invalid value for `record_type` ({0}), must be one of {1}".format(  # noqa: E501
                    record_type, allowed_values
                )
            )

        self._record_type = record_type

    @property
    def source_type(self):
        """Gets the source_type of this AuditLog.  # noqa: E501


        :return: The source_type of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """Sets the source_type of this AuditLog.


        :param source_type: The source_type of this AuditLog.  # noqa: E501
        :type: str
        """
        if source_type is None:
            raise ValueError(
                "Invalid value for `source_type`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["SOURCE_USER", "SOURCE_SYSTEM"]  # noqa: E501
        if source_type not in allowed_values:
            raise ValueError(
                "Invalid value for `source_type` ({0}), must be one of {1}".format(  # noqa: E501
                    source_type, allowed_values
                )
            )

        self._source_type = source_type

    @property
    def timestamp(self):
        """Gets the timestamp of this AuditLog.  # noqa: E501


        :return: The timestamp of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this AuditLog.


        :param timestamp: The timestamp of this AuditLog.  # noqa: E501
        :type: str
        """
        if timestamp is None:
            raise ValueError(
                "Invalid value for `timestamp`, must not be `None`"
            )  # noqa: E501

        self._timestamp = timestamp

    @property
    def user_id(self):
        """Gets the user_id of this AuditLog.  # noqa: E501


        :return: The user_id of this AuditLog.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AuditLog.


        :param user_id: The user_id of this AuditLog.  # noqa: E501
        :type: int
        """
        if user_id is None:
            raise ValueError(
                "Invalid value for `user_id`, must not be `None`"
            )  # noqa: E501

        self._user_id = user_id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this AuditLog.  # noqa: E501


        :return: The workspace_id of this AuditLog.  # noqa: E501
        :rtype: int
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this AuditLog.


        :param workspace_id: The workspace_id of this AuditLog.  # noqa: E501
        :type: int
        """
        if workspace_id is None:
            raise ValueError(
                "Invalid value for `workspace_id`, must not be `None`"
            )  # noqa: E501

        self._workspace_id = workspace_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(AuditLog, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLog):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class V1AuthAccessTokenLoginItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "access_token": "str",
        "token_type": "str",
        "expires_in": "str",
        "refresh_token": "str",
    }

    attribute_map = {
        "access_token": "access_token",
        "token_type": "token_type",
        "expires_in": "expires_in",
        "refresh_token": "refresh_token",
    }

    def __init__(
        self, access_token=None, token_type=None, expires_in=None, refresh_token=None
    ):  # noqa: E501
        """V1AuthAccessTokenLoginItem - a model defined in Swagger"""  # noqa: E501
        self._access_token = None
        self._token_type = None
        self._expires_in = None
        self._refresh_token = None
        self.discriminator = None
        self.access_token = access_token
        self.token_type = token_type
        self.expires_in = expires_in
        self.refresh_token = refresh_token

    @property
    def access_token(self):
        """Gets the access_token of this V1AuthAccessTokenLoginItem.  # noqa: E501


        :return: The access_token of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this V1AuthAccessTokenLoginItem.


        :param access_token: The access_token of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :type: str
        """
        if access_token is None:
            raise ValueError(
                "Invalid value for `access_token`, must not be `None`"
            )  # noqa: E501

        self._access_token = access_token

    @property
    def token_type(self):
        """Gets the token_type of this V1AuthAccessTokenLoginItem.  # noqa: E501


        :return: The token_type of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this V1AuthAccessTokenLoginItem.


        :param token_type: The token_type of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :type: str
        """
        if token_type is None:
            raise ValueError(
                "Invalid value for `token_type`, must not be `None`"
            )  # noqa: E501

        self._token_type = token_type

    @property
    def expires_in(self):
        """Gets the expires_in of this V1AuthAccessTokenLoginItem.  # noqa: E501


        :return: The expires_in of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :rtype: str
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """Sets the expires_in of this V1AuthAccessTokenLoginItem.


        :param expires_in: The expires_in of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :type: str
        """
        if expires_in is None:
            raise ValueError(
                "Invalid value for `expires_in`, must not be `None`"
            )  # noqa: E501

        self._expires_in = expires_in

    @property
    def refresh_token(self):
        """Gets the refresh_token of this V1AuthAccessTokenLoginItem.  # noqa: E501


        :return: The refresh_token of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this V1AuthAccessTokenLoginItem.


        :param refresh_token: The refresh_token of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :type: str
        """
        if refresh_token is None:
            raise ValueError(
                "Invalid value for `refresh_token`, must not be `None`"
            )  # noqa: E501

        self._refresh_token = refresh_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1AuthAccessTokenLoginItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1AuthAccessTokenLoginItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
